pub struct SdmFitResult {
pub photocurrent: f64,
pub saturation_current: f64,
pub resistance_series: f64,
pub resistance_shunt: f64,
pub n_ns_vth: f64,
}Expand description
Result of fitting the single diode model to an IV curve or module specs.
Fields
photocurrent: f64Light-generated (photo) current [A]
saturation_current: f64Diode saturation (dark) current [A]
resistance_series: f64Series resistance [ohm]
resistance_shunt: f64Shunt (parallel) resistance [ohm]
n_ns_vth: f64Product of diode ideality factor, cells in series, and thermal voltage [V]