Module shading

Module shading 

Functions

ground_angle
Angle from horizontal of the line from a point on the row slant length to the bottom of the facing row.
masking_angle
Calculates the masking angle for rows in a standard PV array.
masking_angle_passias
Average masking angle over the slant height of a row (Passias 1984).
projected_solar_zenith_angle
Projected solar zenith angle onto the plane perpendicular to a tracker axis.
shaded_fraction1d
1D shaded fraction for rows (e.g. single-axis trackers).
sky_diffuse_pass_equation
Computes the fraction of sky diffuse irradiance that passes the masking angle.
sky_diffuse_passias
The diffuse irradiance loss caused by row-to-row sky diffuse shading.