ground_angle

Function ground_angle 

pub fn ground_angle(surface_tilt: f64, gcr: f64, slant_height: f64) -> f64
Angle from horizontal of the line from a point on the row slant length to the bottom of the facing row.

Arguments

  • surface_tilt - Surface tilt angle in degrees from horizontal.
  • gcr - Ground coverage ratio (row slant length / row spacing).
  • slant_height - Fraction [0-1] of the module slant height.

Returns

Ground angle (psi) in degrees.