Module snow

Module snow 

Functions

coverage_nrel
Calculates the fraction of a module row’s slant height covered by snow, after accounting for sliding.
dc_loss_nrel
Calculates the fraction of DC capacity lost due to snow coverage on strings.
fully_covered_nrel
Determines whether a module is fully covered by snow based on snowfall rate.
marion_snow_model
Marion snow model.
snow_slides
Simplified Townsend snow model for PV systems.