hsu

Function hsu 

pub fn hsu(
    rainfall: f64,
    cleaning_threshold: f64,
    surface_tilt: f64,
    pm2_5: f64,
    pm10: f64,
    depo_veloc_2_5: f64,
    depo_veloc_10: f64,
    dt_sec: f64,
    previous_mass: f64,
) -> (f64, f64)
HSU soiling model convenience function for a single timestep.

Returns the soiling ratio given current accumulated mass and whether rainfall has cleaned the panels.

Arguments

  • rainfall - Rainfall accumulated in the current period [mm].
  • cleaning_threshold - Rainfall needed to clean panels [mm].
  • surface_tilt - Module tilt [degrees].
  • pm2_5 - PM2.5 concentration [g/m^3].
  • pm10 - PM10 concentration [g/m^3].
  • depo_veloc_2_5 - PM2.5 deposition velocity [m/s], default 0.0009.
  • depo_veloc_10 - PM10 deposition velocity [m/s], default 0.004.
  • dt_sec - Timestep duration [seconds].
  • previous_mass - Accumulated mass from previous timestep [g/m^2].

Returns

A tuple of (soiling_ratio, new_accumulated_mass).