Structs
- Batch
Model Chain - Batch ModelChain – runs the full PV simulation pipeline on a time series using rayon for parallel processing.
- Simulation
Series - Output from batch simulation – one value per timestep.
- Weather
Series - Input data for batch simulation – one value per timestep.
Functions
- airmass_
absolute_ batch - Batch absolute airmass.
- airmass_
relative_ batch - Batch relative airmass for an array of zenith angles.
- aoi_
batch - Batch AOI calculation.
- bird_
batch - Batch Bird clear sky model.
- disc_
batch - Batch DISC decomposition. Returns (dni_vec, kt_vec, airmass_vec).
- erbs_
batch - Batch Erbs decomposition. Returns (dni_vec, dhi_vec).
- extra_
radiation_ batch - Batch extraterrestrial radiation.
- faiman_
batch - Batch Faiman cell temperature.
- iam_
ashrae_ batch - Batch ASHRAE IAM.
- iam_
physical_ batch - Batch Physical IAM.
- ineichen_
batch - Batch Ineichen clear sky model. Returns (ghi_vec, dni_vec, dhi_vec).
- perez_
batch - Batch Perez transposition model.
- pvwatts_
ac_ batch - Batch PVWatts AC power.
- sapm_
cell_ temperature_ batch - Batch SAPM cell temperature. Returns (cell_temp_vec, module_temp_vec).
- solar_
position_ batch - Batch solar position calculation for multiple timestamps. Returns (zenith_vec, azimuth_vec, elevation_vec).
- solar_
position_ batch_ utc - Convenience batch solar position for UTC
NaiveDateTimetimestamps. - total_
irradiance_ batch - Batch get_total_irradiance. Returns PoaComponents for each timestep.